Enum BorrowKind
pub enum BorrowKind {
Shared,
Fake(FakeBorrowKind),
Mut {
kind: MutBorrowKind,
},
}Variants
Data must be immutable and is aliasable.
Fake(FakeBorrowKind)
An immutable, aliasable borrow that is discarded after borrow-checking. Can behave either
like a normal shared borrow or like a special shallow borrow (see FakeBorrowKind).
This is used when lowering index expressions and matches. This is used to prevent code like the following from compiling:
ⓘ
let mut x: &[_] = &[[0, 1]];
let y: &[_] = &[];
let _ = x[0][{x = y; 1}];ⓘ
let mut x = &Some(0);
match *x {
None => (),
Some(_) if { x = &None; false } => (),
Some(_) => (),
}We can also report errors with this kind of borrow differently.
Mut
Data is mutable and not aliasable.
Fields

kind: MutBorrowKindAuto Trait Implementations
impl DynSend for BorrowKind
impl DynSync for BorrowKind
impl Freeze for BorrowKind
impl RefUnwindSafe for BorrowKind
impl Send for BorrowKind
impl Sync for BorrowKind
impl Unpin for BorrowKind
impl UnsafeUnpin for BorrowKind
impl UnwindSafe for BorrowKind