Struct BasicBlock
pub struct BasicBlock {
private_use_as_methods_instead: u32 is 0..=4294967040,
}Expand description
A node in the MIR control-flow graph.
There are no branches (e.g., ifs, function calls, etc.) within a basic block, which makes
it easier to do data-flow analyses and optimizations. Instead, branches are represented
as an edge in a graph between basic blocks.
Basic blocks consist of a series of [statements][Statement], ending with a
[terminator][Terminator]. Basic blocks can have multiple predecessors and successors,
however there is a MIR pass (CriticalCallEdges) that removes critical edges, which
are edges that go from a multi-successor node to a multi-predecessor node. This pass is
needed because some analyses require that there are no critical edges in the CFG.
Note that this type is just an index into Body.basic_blocks;
the actual data that a basic block holds is in [BasicBlockData].
Read more about basic blocks in the rustc-dev-guide.
Fields
private_use_as_methods_instead: u32 is 0..=4294967040Auto Trait Implementations
impl DynSend for BasicBlock
impl DynSync for BasicBlock
impl Freeze for BasicBlock
impl RefUnwindSafe for BasicBlock
impl Send for BasicBlock
impl Sync for BasicBlock
impl Unpin for BasicBlock
impl UnsafeUnpin for BasicBlock
impl UnwindSafe for BasicBlock