Struct Location
pub struct Location {
pub block: BasicBlock,
pub statement_index: usize,
}Expand description
Location represents the position of the start of the statement; or, if
statement_index equals the number of statements, then the start of the
terminator.
Fields
block: BasicBlockThe block that the location is within.
statement_index: usizeAuto Trait Implementations
impl DynSend for Location
impl DynSync for Location
impl Freeze for Location
impl RefUnwindSafe for Location
impl Send for Location
impl Sync for Location
impl Unpin for Location
impl UnsafeUnpin for Location
impl UnwindSafe for Location